@@ -37,6 +37,15 @@ fn main() {
         .flag(
             Flag::new("max-recursion-depth", FlagType::Int)
                 .description("The maximum allowed recursion depth. This is used to avoid crashes."),
+        )
+        .flag(
+            Flag::new("no-leading-eq", FlagType::Bool)
+                .description("Don't include an equal sign at the start of results")
+        )
+        .flag(
+            Flag::new("raw", FlagType::Bool)
+                .description("Only print a single number as the result, nothing else.")
+                .alias("r")
         );
 
     app.run(args);
@@ -83,7 +92,13 @@ fn default_action(context: &Context) {
 
     if context.args.is_empty() {
         // REPL
-        repl::start(&mut parser_context, precision, format);
+        repl::start(
+            &mut parser_context,
+            precision,
+            format,
+            context.bool_flag("no-leading-eq"),
+            context.bool_flag("raw")
+        );
     } else {
         // Direct output
         output::eval(
@@ -92,6 +107,8 @@ fn default_action(context: &Context) {
             precision,
             10u8,
             format,
+            context.bool_flag("no-leading-eq"),
+            context.bool_flag("raw")
         );
     }
 }
